@@ -4,12 +4,12 @@ package org.gcube.portlets.user.gisviewer.client;
 import java.util.List;
 
 import org.gcube.portlets.user.gisviewer.client.commons.beans.DataResult;
+import org.gcube.portlets.user.gisviewer.client.commons.beans.GeoInformationForWMSRequest;
 import org.gcube.portlets.user.gisviewer.client.commons.beans.GisViewerBaseLayerInterface;
 import org.gcube.portlets.user.gisviewer.client.commons.beans.LayerItem;
-import org.gcube.portlets.user.gisviewer.client.commons.beans.LayerItemsResult;
 import org.gcube.portlets.user.gisviewer.client.commons.beans.Property;
 import org.gcube.portlets.user.gisviewer.client.commons.beans.TransectParameters;
-import org.gcube.portlets.user.gisviewer.client.commons.beans.WfsTable;
+import org.gcube.portlets.user.gisviewer.client.commons.beans.WebFeatureTable;
 import org.gcube.portlets.user.gisviewer.client.commons.beans.WmsRequest;
 
 import com.google.gwt.user.client.rpc.AsyncCallback;
@@ -32,33 +32,6 @@ public interface GisViewerServiceAsync {
 	 */
 	public void getDataResult(List<String> urls, AsyncCallback<List<DataResult>> callback);
 
-	/**
-	 * Gets the groups info.
-	 *
-	 * @param groupName the group name
-	 * @param callback the callback
-	 * @return the groups info
-	 */
-	public void getGroupsInfo(String groupName, AsyncCallback<LayerItemsResult> callback);
-
-	/**
-	 * Gets the layers info.
-	 *
-	 * @param layersName the layers name
-	 * @param callback the callback
-	 * @return the layers info
-	 */
-	public void getLayersInfo(List<String> layersName, AsyncCallback<LayerItemsResult> callback);
-
-	/**
-	 * Gets the layers info by layer items.
-	 *
-	 * @param layerItems the layer items
-	 * @param asyncCallback the async callback
-	 * @return the layers info by layer items
-	 */
-	public void getLayersInfoByLayerItems(List<LayerItem> layerItems, AsyncCallback<LayerItemsResult> asyncCallback);
-
 	/**
 	 * Gets the transect parameters.
 	 *
@@ -67,16 +40,6 @@ public interface GisViewerServiceAsync {
 	 */
 	void getTransectParameters(AsyncCallback<TransectParameters> callback);
 
-	/**
-	 * Gets the data result.
-	 *
-	 * @param layerItems the layer items
-	 * @param bbox the bbox
-	 * @param asyncCallback the async callback
-	 * @return the data result
-	 */
-	public void getDataResult(List<LayerItem> layerItems, String bbox, AsyncCallback<List<WfsTable>> asyncCallback);
-
 	/**
 	 * Gets the list property.
 	 *
@@ -95,10 +58,11 @@ public interface GisViewerServiceAsync {
 	 * @param bbox the bbox
 	 * @param maxWFSFeature the max wfs feature
 	 * @param callback the callback
+	 * @param zoomLevel
 	 * @return the data result
 	 */
 	void getDataResult(List<LayerItem> layerItems, String bbox,
-			int maxWFSFeature, AsyncCallback<List<WfsTable>> callback);
+			int maxWFSFeature, int zoomLevel, AsyncCallback<List<WebFeatureTable>> callback);
 
 	/**
 	 * Gets the base layers to gis viewer.
@@ -116,6 +80,24 @@ public interface GisViewerServiceAsync {
 	 */
 	void parseWmsRequest(WmsRequest request, AsyncCallback<String> callback);
 
-//	public void getLayersInfoByLayerConfigurations(List<LayerConfiguration> layerConfigurations, AsyncCallback<LayerItemsResult> asyncCallback);
+
+	/**
+	 * Parses the wms request.
+	 *
+	 * @param wmsRequest the wms request
+	 * @param layerName the layer name
+	 * @param callback the callback
+	 */
+	void parseWmsRequest(String wmsRequest, String layerName,
+		AsyncCallback<GeoInformationForWMSRequest> callback);
+
+	/**
+	 * Gets the gcube security token.
+	 *
+	 * @param callback the callback
+	 * @return the gcube security token
+	 */
+	void getGcubeSecurityToken(AsyncCallback<String> callback);
+	
 
 }
