@@ -171,8 +171,8 @@ public class URLMakers {
 				System.out.println("SERVERTYPE.MAPSERVER srsName: "+srsName);
 				System.out.println("SERVERTYPE.MAPSERVER boundingBox: "+boundingBox);
 			}else {
-				GWT.log("is geoserver append /wfs");
-				link+="/wfs";
+				GWT.log("is geoserver appending suffix /wfs if is not present");
+				link += link.endsWith("wfs")?"":"/wfs";
 				outputformat =  MapServerRecognize.outputFormatRecognize(SERVERTYPE.GEOSEVER, format);
 				srsName = "urn:x-ogc:def:crs:EPSG:4326"; //USE AXIS YX
 				//TODO DEBUG
